@@ -2,8 +2,7 @@ import os, subprocess, sys, logging
 import traceback
 from rich.console import Console
 
-LOG_FILE = os.path.expanduser("~/Desktop/musicDL downloads/logger.log")
-logging.basicConfig(filename=LOG_FILE, level=logging.ERROR, force= True)
+
 
 try:
     from .modules.ytDownloader import yt_downloader
@@ -38,7 +37,11 @@ def create_dir():
     Creates "musicDL downloads" directory on desktop when called. Takes no parameters.
     """
     
-    os.chdir(os.path.expanduser("~/Desktop"))
+    if os.path.isdir(os.path.expanduser("~/Desktop")):
+        os.chdir(os.path.expanduser("~/Desktop"))
+        
+    elif os.path.isdir(os.path.expanduser("~/OneDrive/Desktop")):
+        os.chdir(os.path.expanduser("~/OneDrive/Desktop"))
     try:
         os.chdir("musicDL downloads")
     except:
@@ -63,6 +66,8 @@ def main():
 
         Console().rule("\n[bold]Note that you can always quit the program using \"ctrl+c\" shortcut [bold]", style="black", align="center")
         create_dir()
+        LOG_FILE = os.path.expanduser("~/Desktop/musicDL downloads/logger.log")
+        logging.basicConfig(filename=LOG_FILE, level=logging.ERROR)
         print()
         ch+=1
         
